@@ -1,30 +1,11 @@
 package Qudo::Worker;
 use strict;
 use warnings;
-use base 'Class::Data::Inheritable';
-use Qudo::HookLoader;
-
-__PACKAGE__->mk_classdata(qw/_hooks/);
 
 sub max_retries { 0 }
 sub retry_delay { 0 }
 sub grab_for    { 60*60 } # default setting 1 hour
 sub set_job_status { 0 }  # job process status store for job_status table.
-sub hooks {
-    my $class = shift;
-    $class->_hooks(+{}) unless $class->_hooks;
-    $class->_hooks;
-}
-
-sub register_hooks {
-    my ($class, @hook_modules) = @_;
-    Qudo::HookLoader->register_hooks($class, \@hook_modules);
-}
-
-sub unregister_hooks {
-    my ($class, @hook_modules) = @_;
-    Qudo::HookLoader->unregister_hooks($class, \@hook_modules);
-}
 
 sub work_safely {
     my ($class, $manager, $job) = @_;
@@ -74,7 +55,7 @@ Qudo::Worker - superclass for defining task behavior of Qudo's work
 
         $job->completed();
     }
-    ### end of Myworker package.
+    1;
 
 =head1 DESCRIPTION
 
